@@ -29,7 +29,6 @@ import socket
 import types
 import random
 import signal
-import inspect
 import multiprocessing
 import logging
 
@@ -251,7 +250,7 @@ def run_command(host, command="uname -a", username=None, password=None,
         timeout = None
     if not username:
         username = getpass.getuser()
-    if bufsize == -1 and script:
+    if bufsize == -1 and script and os.path.exists(script):
         bufsize = os.path.getsize(script) + 1024
 
     script_parameters = None
@@ -371,7 +370,8 @@ def run_command(host, command="uname -a", username=None, password=None,
                 if check_prompt:
                     if password in el or 'assword:' in el or \
                             '[sudo] password' in el or el.strip() == '' or \
-                            el.strip() in defaults.sudo_message:
+                            el.strip() in defaults.sudo_message or \
+                            el.strip().startswith('sudo:'):
                         skip = True
                     else:
                         check_prompt = False
@@ -486,7 +486,7 @@ def run(host_range, command, username=None, password=None, sudo=False,
 
     pool = multiprocessing.Pool(processes=jobs, initializer=init_worker)
     if not chunksize:
-        if jobs >= len(hosts):
+        if jobs == 1 or jobs >= len(hosts):
             chunksize = 1
         else:
             chunksize = int(len(hosts) / jobs) - 1
